@@ -8,7 +8,9 @@ CARGO_HOME=$(mktemp -d 2>/dev/null || mktemp -d -t 'cargo-home')
 export CARGO_HOME
 export PATH="$CARGO_HOME/bin:$PATH"
 
-"./$1" --self-install
+TMPDIR=$(mktemp -d 2>/dev/null || mktemp -d -t tmp)
+cp "./$1" "$TMPDIR/cargo-binstall"
+"$TMPDIR/cargo-binstall" --self-install
 
 cargo binstall -vV
 cargo install --list
